/*
 *  Copyright (C) 2013  Thadeu Lima de Souza Cascardo <cascardo@cascardo.info>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along
 *  with this program; if not, write to the Free Software Foundation, Inc.,
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

#include <sgp/friend.h>
#include <sgp/channel.h>
#include <stdlib.h>

struct sgp_friend {
	char *alias;
	struct sgp_channel *channel;
};

struct sgp_friend * sgp_friend_new(char *alias)
{
	struct sgp_friend *friend;
	friend = malloc(sizeof(*friend));
	if (!friend)
		return NULL;
	friend->alias = strdup(alias);
	if (!friend->alias)
		goto out;
	friend->channel = NULL;
	return friend;
out:
	free(friend);
	return NULL;
}

void sgp_friend_destroy(struct sgp_friend *friend)
{
	free(friend->alias);
	free(friend);
}

char * sgp_friend_get_alias(struct sgp_friend *friend)
{
	return friend->alias;
}

/*
 * Get the channel used for communication with a friend.
 */
struct sgp_channel * sgp_friend_get_channel(struct sgp_friend *friend)
{
	/*
	 * TODO: A friend may have multiple channels for contact. We
	 * should either implement this at the core (at sgp_send, for
	 * example), or create a channel that encapsulates that.
	 */
	return friend->channel;
}

void sgp_friend_set_channel(struct sgp_friend *friend,
				struct sgp_channel *channel)
{
	friend->channel = channel;
}
